==> cloudnary_flutter-0.0.4.tar.gz: android/src/main/java/com/clodnary/cloudnary_flutter/ImageUploading.kt <==
package com.clodnary.cloudnary_flutter

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.widget.TextView
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.api
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.apiSecret
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.cloudName
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.notificationUrl
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.path
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.publicId
import com.cloudinary.Cloudinary
import com.cloudinary.android.MediaManager
import com.cloudinary.android.callback.ErrorInfo
import com.cloudinary.android.callback.UploadCallback

class ImageUploading : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_image_uploading)

        val statusText = findViewById<TextView>(R.id.textView)

//        val cloudinary = Cloudinary("cloudinary://515312939158734:NKhDxj3RlKJn6SzQRjCtikN_ow8@eureka-campaign-associates-pte-ltd")

        val config: MutableMap<String, String> = HashMap()
        config["cloud_name"] = cloudName
        config["api_key"] = api
        config["api_secret"] = apiSecret

        try {
            MediaManager.init(this, config)
        }catch (e:Exception){}

        MediaManager.get().upload(path)
                .option("public_id", publicId)
                .option("background_removal", "cloudinary_ai:fine_edges")
              .option("notification_url", notificationUrl)
                .callback(object: UploadCallback {
                    override fun onStart(requestId: String) {
                        Log.d("cloudnary", "start")
                        statusText.text = "Started"
                    }

                    override fun onProgress(requestId: String?, bytes: Long, totalBytes: Long) {
                        Log.d("cloudnary", "uploading... => $bytes")
                        statusText.text = ((bytes*100)/totalBytes).toString() + "% uploaded"
                    }

                    override fun onSuccess(requestId: String?, resultData: MutableMap<Any?, Any?>?) {
                        Log.d("cloudnary", "success... => $requestId")
                        Log.d("cloudnary", "response... => $resultData")
                        statusText.text = "Uploaded successfully"

                        finish()
                        CloudnaryFlutterPlugin.globalResult?.success("response $resultData")
                    }

                    override fun onError(requestId: String?, error: ErrorInfo?) {
                        finish()
                        CloudnaryFlutterPlugin.globalResult?.success(error.toString())
                    }

                    override fun onReschedule(requestId: String?, error: ErrorInfo?) {
                        Log.d("cloudnary", "error... => $error")
                    }
                }).dispatch();


    }
}

==> cloudnary_flutter-0.0.6.tar.gz: android/src/main/java/com/clodnary/cloudnary_flutter/ImageUploading.kt <==
package com.clodnary.cloudnary_flutter

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.widget.TextView
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.api
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.apiSecret
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.cloudName
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.notificationUrl
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.path
import com.clodnary.cloudnary_flutter.CloudnaryFlutterPlugin.Companion.publicId
import com.cloudinary.Cloudinary
import com.cloudinary.android.MediaManager
import com.cloudinary.android.callback.ErrorInfo
import com.cloudinary.android.callback.UploadCallback
import org.json.JSONObject

class ImageUploading : AppCompatActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_image_uploading)

        val statusText = findViewById<TextView>(R.id.textView)

//        val cloudinary = Cloudinary("cloudinary://515312939158734:NKhDxj3RlKJn6SzQRjCtikN_ow8@eureka-campaign-associates-pte-ltd")

        val config: MutableMap<String, String> = HashMap()
        config["cloud_name"] = cloudName
        config["api_key"] = api
        config["api_secret"] = apiSecret

        try {
            MediaManager.init(this, config)
        }catch (e:Exception){}

        MediaManager.get().upload(path)
                .option("public_id", publicId)
                .option("background_removal", "cloudinary_ai:fine_edges")
              .option("notification_url", notificationUrl)
                .callback(object: UploadCallback {
                    override fun onStart(requestId: String) {
                        Log.d("cloudnary", "start")
//                        statusText.text = "Started"
                    }

                    override fun onProgress(requestId: String?, bytes: Long, totalBytes: Long) {
                        Log.d("cloudnary", "uploading... => $bytes")
                        statusText.text = ((bytes*100)/totalBytes).toString() + "% uploaded"
                    }

                    override fun onSuccess(requestId: String?, resultData: MutableMap<Any?, Any?>?) {
                        Log.d("cloudnary", "success... => $requestId")
                        Log.d("cloudnary", "response... => $resultData")
                        statusText.text = "Uploaded successfully"

                        val url:String = resultData!!["url"] as String

                        finish()
                        CloudnaryFlutterPlugin.globalResult?.success(url)
                    }

                    override fun onError(requestId: String?, error: ErrorInfo?) {
                        finish()
                        CloudnaryFlutterPlugin.globalResult?.success(error.toString())
                    }

                    override fun onReschedule(requestId: String?, error: ErrorInfo?) {
                        Log.d("cloudnary", "error... => $error")
                    }
                }).dispatch();


    }
}
